@@ -8,12 +8,94 @@
  use strict;
  use warnings;
 #-------------------------------------------------
- $Tk::Image::Calculation::VERSION = '0.02';
+ $Tk::Image::Calculation::VERSION = '0.03';
 #-------------------------------------------------
  sub new
  	{
- 	my ($class) = @_;
- 	my $self = {};
+ 	my ($class, %args) = @_;
+ 	my $self;
+=head1
+ -form	=> circle oval
+ -points	=> [x1, y1, x2, y2]
+ -subset	=> all points_outside points_inside lines_outside lines_inside
+=cut
+#-------------------------------------------------
+ if(%args)
+ { 
+ my @parameter = ($class, $args{-points}[0], $args{-points}[1], $args{-points}[2], $args{-points}[3]);
+ FORM:
+ 	{
+ 	($args{-form} eq "oval")	&& do
+ 		{
+ 		OVAL:
+ 			{
+ 			($args{-subset} eq "points_outside")	&& do 
+ 				{
+ 				$self = GetPointsOutOval(@parameter);
+ 				last(FORM);
+ 				};
+ 			($args{-subset} eq "points_inside")	&& do
+ 				{
+ 				$self = GetPointsInOval(@parameter);
+ 				last(FORM);
+ 				};
+ 			($args{-subset} eq "lines_outside")	&& do
+ 				{
+ 				$self = GetLinesOutOval(@parameter);
+ 				last(FORM);
+ 				};
+ 			($args{-subset} eq "lines_inside")	&& do
+ 				{
+ 				$self = GetLinesInOval(@parameter);
+ 				last(FORM);
+ 				};
+ 			($args{-subset} eq "all")		&& do
+ 				{
+ 				$self = GetPointsOval(@parameter);
+ 				last(FORM);
+ 				};
+ 			}
+ 		};
+ 	($args{-form} eq "circle")	&& do
+ 		{
+ 		CIRCLE:
+ 			{
+ 			($args{-subset} eq "points_outside")	&& do
+ 				{
+ 				$self = GetPointsOutCircle(@parameter);
+ 				last(FORM);
+ 				};
+ 			($args{-subset} eq "points_inside")	&& do
+ 				{
+ 				$self = GetPointsInCircle(@parameter);
+ 				last(FORM);
+ 				};
+ 			($args{-subset} eq "lines_outside")	&& do
+ 				{
+ 				$self = GetLinesOutCircle(@parameter);
+ 				last(FORM);
+ 				};
+ 			($args{-subset} eq "lines_inside")	&& do
+ 				{
+ 				$self = GetLinesInCircle(@parameter);
+ 				last(FORM);
+ 				};
+ 			($args{-subset} eq "all")		&& do
+ 				{
+ 				$self = GetPointsCircle(@parameter);
+ 				last(FORM);
+ 				};
+ 			}
+ 		};
+ 	warn("wrong args in call to Tk::Image::Calculation::new()\n");
+ 	$self = [];
+ 	} 		
+ }
+#-------------------------------------------------
+ 	else
+ 		{
+ 		$self = {};
+ 		}
  	bless($self, $class || ref($class));
  	return($self);
  	}
@@ -21,53 +103,76 @@
  sub GetPointsOval
  	{
  	my ($self, $p_x1, $p_y1, $p_x2, $p_y2) = @_;
- 	my (@points_out, @points_in, @lines_out, @lines_in, $d, $pos_x_p, $pos_x_n, $y, $y1, $y2);
+ 	my (@points_out, @points_in, @lines_out, @lines_in);
+ 	my ($pos_x_p, $pos_x_n, $pos_y1, $pos_y2);
+ 	my ($y, $y1, $y2);
+ 	my $diff;
  	($p_x1, $p_x2) = ($p_x2, $p_x1) if($p_x1 > $p_x2);
  	($p_y1, $p_y2) = ($p_y2, $p_y1) if($p_y1 > $p_y2);
  	my $width = ($p_x2 - $p_x1);
  	my $height= ($p_y2 - $p_y1);
- 	return([], [], [], []) if(($width < 5) || ($height < 5));
+ 	if(($width < 5) || ($height < 5))
+ 		{
+ 		return({
+ 			points_outside	=> [],
+ 			points_inside	=> [],
+ 			lines_outside	=> [],
+ 			lines_inside	=> []
+ 			});
+ 		}
  	my $a = ($width / 2);
- 	my $a2  = $a**2;
+ 	my $a2  = $a ** 2;
  	my $b = ($height / 2);
  	my $c = ($b / $a);
  	my $pos_x = ($a + $p_x1);
  	for(my $x = 0; $x <= $a; $x++)
  		{
- 		$d = int($c * sqrt($a2 - ($x**2)));
- 		$y1 = ($b - $d);
- 		$y2 = ($b + $d);
+ 		$diff = int($c * sqrt($a2 - ($x ** 2)));
+ 		$y1 = ($b - $diff);
+ 		$y2 = ($b + $diff);
+ 		$pos_y1 = ($y1 + $p_y1);
+ 		$pos_y2 = ($y2 + $p_y1);
 		$pos_x_p = int($x + $pos_x);
  		$pos_x_n = int(-$x + $pos_x);
- 		push(@lines_out, [$pos_x_p, $p_y1, $pos_x_p, ($y1 + $p_y1)]);
- 		push(@lines_out, [$pos_x_n, $p_y1, $pos_x_n, ($y1 + $p_y1)]);
+ 		push(@lines_out, [$pos_x_p, $p_y1, $pos_x_p, $pos_y1]);
+ 		push(@lines_out, [$pos_x_n, $p_y1, $pos_x_n, $pos_y1]);
+		push(@lines_in, [$pos_x_p, $pos_y1, $pos_x_p, $pos_y2]);
+ 		push(@lines_in, [$pos_x_n, $pos_y1, $pos_x_n, $pos_y2]);
+ 		push(@lines_out, [$pos_x_p, $pos_y2, $pos_x_p, $p_y2]);
+ 		push(@lines_out, [$pos_x_n, $pos_y2, $pos_x_n, $p_y2]);
  		for($y = 0; $y <= $y1; $y++)
  			{
-			push(@points_out, [$pos_x_p, ($y + $p_y1)]);
-			push(@points_out, [$pos_x_n, ($y + $p_y1)]);
+ 			$pos_y1 = ($y + $p_y1);
+			push(@points_out, [$pos_x_p, $pos_y1]);
+			push(@points_out, [$pos_x_n, $pos_y1]);
  			} 
- 		push(@lines_in, [$pos_x_p, ($y1 + $p_y1), $pos_x_p, ($y2 + $p_y1)]);
- 		push(@lines_in, [$pos_x_n, ($y1 + $p_y1), $pos_x_n, ($y2 + $p_y1)]);
  		for($y = $y1; $y <= $y2; $y++)
  			{
- 			push(@points_in, [$pos_x_p, ($y + $p_y1)]);
- 			push(@points_in, [$pos_x_n, ($y + $p_y1)]);
+ 			$pos_y1 = ($y + $p_y1);
+ 			push(@points_in, [$pos_x_p, $pos_y1]);
+ 			push(@points_in, [$pos_x_n, $pos_y1]);
  			}
- 		push(@lines_out, [$pos_x_p, ($y2 + $p_y1), $pos_x_p, ($height + $p_y1)]);
- 		push(@lines_out, [$pos_x_n, ($y2 + $p_y1), $pos_x_n, ($height + $p_y1)]);
  		for($y = $y2; $y <= $height; $y++)
  			{
- 			push(@points_out, [$pos_x_p, ($y + $p_y1)]);
- 			push(@points_out, [$pos_x_n, ($y + $p_y1)]);
+ 			$pos_y1 = ($y + $p_y1);
+ 			push(@points_out, [$pos_x_p, $pos_y1]);
+ 			push(@points_out, [$pos_x_n, $pos_y1]);
  			}
  		}
- 	return(\@points_out, \@points_in, \@lines_out, \@lines_in);
+ 	return({
+ 		points_outside	=> \@points_out, 
+ 		points_inside	=> \@points_in, 
+ 		lines_outside	=> \@lines_out, 
+ 		lines_inside	=> \@lines_in
+ 		});
  	}
 #-------------------------------------------------
  sub GetPointsInOval
  	{
  	my ($self, $p_x1, $p_y1, $p_x2, $p_y2) = @_;
- 	my ($d, $pos_x_p, $pos_x_n, $y, $y1, $y2);
+ 	my ($pos_x_p, $pos_x_n, $pos_y1);
+ 	my ($y, $y1, $y2);
+ 	my $diff;
  	($p_x1, $p_x2) = ($p_x2, $p_x1) if($p_x1 > $p_x2);
  	($p_y1, $p_y2) = ($p_y2, $p_y1) if($p_y1 > $p_y2);
  	my $width = ($p_x2 - $p_x1);
@@ -81,15 +186,16 @@
  	my @points_in;
  	for(my $x = 0; $x <= $a; $x++)
  		{
- 		$d = int($c * sqrt($a2 - ($x**2)));
- 		$y1 = ($b - $d);
- 		$y2 = ($b + $d);
+ 		$diff = int($c * sqrt($a2 - ($x**2)));
+ 		$y1 = ($b - $diff);
+ 		$y2 = ($b + $diff);
 		$pos_x_p = int($x + $pos_x);
  		$pos_x_n = int(-$x + $pos_x);
  		for($y = $y1; $y <= $y2; $y++)
  			{
- 			push(@points_in, [$pos_x_p, ($y + $p_y1)]);
- 			push(@points_in, [$pos_x_n, ($y + $p_y1)]);
+ 			$pos_y1 = ($y + $p_y1);
+ 			push(@points_in, [$pos_x_p, $pos_y1]);
+ 			push(@points_in, [$pos_x_n, $pos_y1]);
  			}
  		}
  	return(\@points_in);
@@ -98,7 +204,9 @@
  sub GetPointsOutOval
  	{
  	my ($self, $p_x1, $p_y1, $p_x2, $p_y2) = @_;
- 	my ($d, $pos_x_p, $pos_x_n, $y, $y1, $y2);
+ 	my ($pos_x_p, $pos_x_n, $pos_y1);
+ 	my ($y, $y1, $y2);
+ 	my $diff;
  	($p_x1, $p_x2) = ($p_x2, $p_x1) if($p_x1 > $p_x2);
  	($p_y1, $p_y2) = ($p_y2, $p_y1) if($p_y1 > $p_y2);
  	my $width = ($p_x2 - $p_x1);
@@ -112,20 +220,22 @@
  	my @points_out;
  	for(my $x = 0; $x <= $a; $x++)
  		{
- 		$d = int($c * sqrt($a2 - ($x**2)));
- 		$y1 = ($b - $d);
- 		$y2 = ($b + $d);
+ 		$diff = int($c * sqrt($a2 - ($x**2)));
+ 		$y1 = ($b - $diff);
+ 		$y2 = ($b + $diff);
 		$pos_x_p = int($x + $pos_x);
  		$pos_x_n = int(-$x + $pos_x);
  		for($y = 0; $y <= $y1; $y++)
  			{
-			push(@points_out, [$pos_x_p, ($y + $p_y1)]);
-			push(@points_out, [$pos_x_n, ($y + $p_y1)]);
+ 			$pos_y1 = ($y + $p_y1);
+			push(@points_out, [$pos_x_p, $pos_y1]);
+			push(@points_out, [$pos_x_n, $pos_y1]);
  			} 
  		for($y = $y2; $y <= $height; $y++)
  			{
- 			push(@points_out, [$pos_x_p, ($y + $p_y1)]);
- 			push(@points_out, [$pos_x_n, ($y + $p_y1)]);
+ 			$pos_y1 = ($y + $p_y1);
+ 			push(@points_out, [$pos_x_p, $pos_y1]);
+ 			push(@points_out, [$pos_x_n, $pos_y1]);
  			}
  		}
  	return(\@points_out);
@@ -134,7 +244,9 @@
  sub GetLinesInOval
  	{
  	my ($self, $p_x1, $p_y1, $p_x2, $p_y2) = @_;
- 	my ($d, $pos_x_p, $pos_x_n, $y, $y1, $y2);
+ 	my ($pos_x_p, $pos_x_n, $pos_y1, $pos_y2);
+ 	my ($y, $y1, $y2);
+ 	my $diff;
  	($p_x1, $p_x2) = ($p_x2, $p_x1) if($p_x1 > $p_x2);
  	($p_y1, $p_y2) = ($p_y2, $p_y1) if($p_y1 > $p_y2);
  	my $width = ($p_x2 - $p_x1);
@@ -148,13 +260,15 @@
  	my @lines_in;
  	for(my $x = 0; $x <= $a; $x++)
  		{
- 		$d = int($c * sqrt($a2 - ($x**2)));
- 		$y1 = ($b - $d);
- 		$y2 = ($b + $d);
+ 		$diff = int($c * sqrt($a2 - ($x**2)));
+ 		$y1 = ($b - $diff);
+ 		$y2 = ($b + $diff);
 		$pos_x_p = int($x + $pos_x);
  		$pos_x_n = int(-$x + $pos_x);
- 		push(@lines_in, [$pos_x_p, ($y1 + $p_y1), $pos_x_p, ($y2 + $p_y1)]);
- 		push(@lines_in, [$pos_x_n, ($y1 + $p_y1), $pos_x_n, ($y2 + $p_y1)]);
+ 		$pos_y1 = ($y1 + $p_y1);
+ 		$pos_y2 = ($y2 + $p_y1);
+ 		push(@lines_in, [$pos_x_p, $pos_y1, $pos_x_p, $pos_y2]);
+ 		push(@lines_in, [$pos_x_n, $pos_y1, $pos_x_n, $pos_y2]);
  		}
  	return(\@lines_in);
  	}
@@ -162,7 +276,9 @@
  sub GetLinesOutOval
  	{
  	my ($self, $p_x1, $p_y1, $p_x2, $p_y2) = @_;
- 	my ($d, $pos_x_p, $pos_x_n, $y, $y1, $y2);
+ 	my ($pos_x_p, $pos_x_n, $pos_y1, $pos_y2);
+ 	my ($y, $y1, $y2);
+ 	my $diff;
  	($p_x1, $p_x2) = ($p_x2, $p_x1) if($p_x1 > $p_x2);
  	($p_y1, $p_y2) = ($p_y2, $p_y1) if($p_y1 > $p_y2);
  	my $width = ($p_x2 - $p_x1);
@@ -176,15 +292,17 @@
  	my @lines_out;
  	for(my $x = 0; $x <= $a; $x++)
  		{
- 		$d = int($c * sqrt($a2 - ($x**2)));
- 		$y1 = ($b - $d);
- 		$y2 = ($b + $d);
+ 		$diff = int($c * sqrt($a2 - ($x**2)));
+ 		$y1 = ($b - $diff);
+ 		$y2 = ($b + $diff);
 		$pos_x_p = int($x + $pos_x);
  		$pos_x_n = int(-$x + $pos_x);
- 		push(@lines_out, [$pos_x_p, $p_y1, $pos_x_p, ($y1 + $p_y1)]);
- 		push(@lines_out, [$pos_x_n, $p_y1, $pos_x_n, ($y1 + $p_y1)]); 
- 		push(@lines_out, [$pos_x_p, ($y2 + $p_y1), $pos_x_p, ($height + $p_y1)]);
- 		push(@lines_out, [$pos_x_n, ($y2 + $p_y1), $pos_x_n, ($height + $p_y1)]);
+ 		$pos_y1 = ($y1 + $p_y1);
+ 		$pos_y2 = ($y2 + $p_y1);
+ 		push(@lines_out, [$pos_x_p, $p_y1, $pos_x_p, $pos_y1]);
+ 		push(@lines_out, [$pos_x_n, $p_y1, $pos_x_n, $pos_y1]); 
+ 		push(@lines_out, [$pos_x_p, $pos_y2, $pos_x_p, $p_y2]);
+ 		push(@lines_out, [$pos_x_n, $pos_y2, $pos_x_n, $p_y2]);
  		}
  	return(\@lines_out);
  	}
@@ -192,65 +310,83 @@
  sub GetPointsCircle
  	{
  	my ($self, $p_x1, $p_y1, $p_x2, $p_y2) = @_;
- 	my (@points_out, @points_in, @lines_out, @lines_in, $x2py2, $pos_x, $pos_y, $diff_y);
+ 	my (@points_out, @points_in, @lines_out, @lines_in);
+ 	my ($x2py2, $pos_x, $pos_y1, $pos_y2);
+ 	my ($i_x2, $i_y);
+ 	my $diff_y;
  	($p_x1, $p_x2) = ($p_x2, $p_x1) if($p_x1 > $p_x2); 
  	($p_y1, $p_y2) = ($p_y2, $p_y1) if($p_y1 > $p_y2);
  	my $width = ($p_x2 - $p_x1);
  	my $height= ($p_y2 - $p_y1);
- 	return([], [], [], []) if(($width < 5) || ($height < 5));
+ 	if(($width < 5) || ($height < 5))
+ 		{
+ 		return({
+ 			points_outside	=> [],
+ 			points_inside	=> [],
+ 			lines_outside	=> [],
+ 			lines_inside	=> []
+ 			});
+ 		}
  	my $r = int($width / 2);
  	my $r2 = ($r**2);  
  	my $coord_x = ($p_x1 + $r);
  	my $coord_y = ($p_y1 + $r);
  	for(my $i_x = -$r; $i_x <= $r; $i_x++)
  		{
- 		$pos_x = ($coord_x + $i_x);
- 		$diff_y = sqrt($r2 - ($i_x**2));
- 		push(@lines_out, [$pos_x, $p_y1, $pos_x, ($coord_y - $diff_y)]);
- 		push(@lines_out, [$pos_x, ($coord_y + $diff_y), $pos_x, $p_y2]);
- 		push(@lines_in, [$pos_x, ($coord_y - $diff_y), $pos_x, ($coord_y + $diff_y)]);
- 		for(my $i_y = $r; $i_y >= -$r; $i_y--)
+ 		$i_x2 = ($i_x ** 2);
+ 		$diff_y = sqrt($r2 - $i_x2);
+		$pos_x = ($coord_x + $i_x);
+ 		$pos_y1 = ($coord_y + $diff_y);
+ 		$pos_y2 = ($coord_y - $diff_y);
+ 		push(@lines_out, [$pos_x, $p_y1, $pos_x, $pos_y2]);
+ 		push(@lines_out, [$pos_x, $pos_y1, $pos_x, $p_y2]);
+ 		push(@lines_in, [$pos_x, $pos_y2, $pos_x, $pos_y1]);
+ 		for($i_y = $r; $i_y >= -$r; $i_y--)
  			{
- 			$pos_y = ($coord_y + $i_y);
- 			$x2py2 = (($i_x**2) + ($i_y**2));
+ 			$pos_y1 = ($coord_y + $i_y);
+ 			$x2py2 = ($i_x2 + ($i_y ** 2));
  			if($x2py2 < $r2)
  				{
- 				push(@points_in, [$pos_x, $pos_y]);
+ 				push(@points_in, [$pos_x, $pos_y1]);
  				}
  			elsif($x2py2 > $r2)
  				{
- 				push(@points_out, [$pos_x, $pos_y]);
+ 				push(@points_out, [$pos_x, $pos_y1]);
  				}
  			} 
  		}
- 	return(\@points_out, \@points_in, \@lines_out, \@lines_in);
+ 	return({
+ 		points_outside	=> \@points_out,
+ 		points_inside	=>  \@points_in, 
+ 		lines_outside	=> \@lines_out, 
+ 		lines_inside	=> \@lines_in
+ 		});
  	}
 #-------------------------------------------------
  sub GetPointsInCircle
  	{
  	my ($self, $p_x1, $p_y1, $p_x2, $p_y2) = @_;
- 	my ($x2py2, $pos_x, $pos_y);
+ 	my ($x2py2, $i_y);
  	($p_x1, $p_x2) = ($p_x2, $p_x1) if($p_x1 > $p_x2); 
  	($p_y1, $p_y2) = ($p_y2, $p_y1) if($p_y1 > $p_y2);
  	my $width = ($p_x2 - $p_x1);
  	my $height= ($p_y2 - $p_y1);
  	return([]) if(($width < 5) || ($height < 5));
  	my $r = int($width / 2);
- 	my $r2 = ($r**2);  
+ 	my $r2 = ($r ** 2);  
  	my $coord_x = ($p_x1 + $r);
  	my $coord_y = ($p_y1 + $r);
  	my @points_in;
  	for(my $i_x = -$r; $i_x <= $r; $i_x++)
  		{
- 		$pos_x = ($coord_x + $i_x);
- 		for(my $i_y = $r; $i_y >= -$r; $i_y--)
+ 		for($i_y = $r; $i_y >= -$r; $i_y--)
  			{
- 			$pos_y = ($coord_y + $i_y);
- 			$x2py2 = (($i_x**2) + ($i_y**2));
+ 			$x2py2 = (($i_x ** 2) + ($i_y ** 2));
  			if($x2py2 < $r2)
  				{
- 				push(@points_in, [$pos_x, $pos_y]);
- 				} 			} 
+ 				push(@points_in, [($coord_x + $i_x), ($coord_y + $i_y)]);
+ 				} 			
+ 			} 
  		}
  	return(\@points_in);
  	}
@@ -258,27 +394,25 @@
  sub GetPointsOutCircle
  	{
  	my ($self, $p_x1, $p_y1, $p_x2, $p_y2) = @_;
- 	my ($x2py2, $pos_x, $pos_y);
+ 	my ($x2py2, $i_y);
  	($p_x1, $p_x2) = ($p_x2, $p_x1) if($p_x1 > $p_x2); 
  	($p_y1, $p_y2) = ($p_y2, $p_y1) if($p_y1 > $p_y2);
  	my $width = ($p_x2 - $p_x1);
  	my $height= ($p_y2 - $p_y1);
  	return([]) if(($width < 5) || ($height < 5));
  	my $r = int($width / 2);
- 	my $r2 = ($r**2);  
+ 	my $r2 = ($r ** 2);  
  	my $coord_x = ($p_x1 + $r);
  	my $coord_y = ($p_y1 + $r);
  	my @points_out;
  	for(my $i_x = -$r; $i_x <= $r; $i_x++)
  		{
- 		$pos_x = ($coord_x + $i_x);
- 		for(my $i_y = $r; $i_y >= -$r; $i_y--)
+ 		for($i_y = $r; $i_y >= -$r; $i_y--)
  			{
- 			$pos_y = ($coord_y + $i_y);
- 			$x2py2 = (($i_x**2) + ($i_y**2));
+ 			$x2py2 = (($i_x ** 2) + ($i_y ** 2));
  			if($x2py2 > $r2)
  				{
- 				push(@points_out, [$pos_x, $pos_y]);
+ 				push(@points_out, [($coord_x + $i_x), ($coord_y + $i_y)]);
  				}
  			} 
  		}
@@ -288,21 +422,21 @@
  sub GetLinesInCircle
  	{
  	my ($self, $p_x1, $p_y1, $p_x2, $p_y2) = @_;
- 	my ($x2py2, $pos_x, $pos_y, $diff_y);
+ 	my ($x2py2, $pos_x, $diff_y);
  	($p_x1, $p_x2) = ($p_x2, $p_x1) if($p_x1 > $p_x2); 
  	($p_y1, $p_y2) = ($p_y2, $p_y1) if($p_y1 > $p_y2);
  	my $width = ($p_x2 - $p_x1);
  	my $height= ($p_y2 - $p_y1);
  	return([]) if(($width < 5) || ($height < 5));
  	my $r = int($width / 2);
- 	my $r2 = ($r**2);  
+ 	my $r2 = ($r ** 2);  
  	my $coord_x = ($p_x1 + $r);
  	my $coord_y = ($p_y1 + $r);
  	my @lines_in;
  	for(my $i_x = -$r; $i_x <= $r; $i_x++)
  		{
  		$pos_x = ($coord_x + $i_x);
- 		$diff_y = sqrt($r2 - ($i_x**2));
+ 		$diff_y = sqrt($r2 - ($i_x ** 2));
  		push(@lines_in, [$pos_x, ($coord_y - $diff_y), $pos_x, ($coord_y + $diff_y)]);
  		}
  	return(\@lines_in);
@@ -311,21 +445,21 @@
  sub GetLinesOutCircle
  	{
  	my ($self, $p_x1, $p_y1, $p_x2, $p_y2) = @_;
- 	my ($x2py2, $pos_x, $pos_y, $diff_y);
+ 	my ($x2py2, $pos_x, $diff_y);
  	($p_x1, $p_x2) = ($p_x2, $p_x1) if($p_x1 > $p_x2); 
  	($p_y1, $p_y2) = ($p_y2, $p_y1) if($p_y1 > $p_y2);
  	my $width = ($p_x2 - $p_x1);
  	my $height= ($p_y2 - $p_y1);
  	return([]) if(($width < 5) || ($height < 5));
  	my $r = int($width / 2);
- 	my $r2 = ($r**2);  
+ 	my $r2 = ($r ** 2);  
  	my $coord_x = ($p_x1 + $r);
  	my $coord_y = ($p_y1 + $r);
  	my @lines_out;
  	for(my $i_x = -$r; $i_x <= $r; $i_x++)
  		{
  		$pos_x = ($coord_x + $i_x);
- 		$diff_y = sqrt($r2 - ($i_x**2));
+ 		$diff_y = sqrt($r2 - ($i_x ** 2));
  		push(@lines_out, [$pos_x, $p_y1, $pos_x, ($coord_y - $diff_y)]);
  		push(@lines_out, [$pos_x, ($coord_y + $diff_y), $pos_x, $p_y2]);
  		}
@@ -361,9 +495,32 @@ Tk::Image::Calculation - Perl extension for graphic calculations
 
 =head1 CONSTRUCTOR
 
- my $object = Tk::Image::Calculation->new();
+=item my $object = Tk::Image::Calculation->new();
 
-=head1 FUNCTIONS
+ Returns an empty object just for calling the methods.
+
+=item my $object = Tk::Image::Calculation->new(
+ 	-points	=> [$x1, $y1, $x2, $y2],
+ 	-form	=> "oval", # or circle
+ 	-subset	=> "points_outside, # or points_inside, lines_inside, lines_outside
+ 	);
+
+ Returns an arrayreference blessed as object with lines or points.
+
+=item my $object = Tk::Image::Calculation->new(
+ 	-points	=> [$x1, $y1, $x2, $y2],
+ 	-form	=> "circle", # or oval
+ 	-subset	=> "all"
+ 	);
+
+ Returns a hashreference blessed as object with the following keys.
+ 	points_outside
+ 	points_inside
+ 	lines_outside
+ 	lines_inside
+ The values of the keys are arrayreferences with lines or points.
+
+=head1 METHODS
 
  Two points are handed over to the functions for Oval and Circle. 
  In the following form ($x1, $y1, $x2, $y2).
@@ -376,8 +533,12 @@ Tk::Image::Calculation - Perl extension for graphic calculations
 =item GetPointsOval
 
  Takes over two points as parameters.
- Returns four array references in the following sequence.
- ($ref_points_outside, $ref_points_inside, $ref_lines_outside, $ref_lines_inside) 
+ Returns a hashreferences with the following keys.
+ 	points_outside 
+ 	points_inside
+ 	lines_outside 
+ 	lines_inside
+ The values of the keys are arrayreferences with points or lines. 
 
 =item GetPointsInOval, GetPointsOutOval, GetLinesInOval, GetLinesOutOval
 
@@ -428,3 +589,5 @@ at your option, any later version of Perl 5 you may have available.
 
 
 
+
+
